function output = SMA(X,int)

%--------------------------------------------------------------------------
% USAGE : [Time series] = SMA(Original Time Series, time period for moving average)
%--------------------------------------------------------------------------
% DESCRIPTION : This function computes the simple average of a time series
%               over the past "int" periods
%--------------------------------------------------------------------------
% INPUTS:  X = column vector of a time series.
%          int = time period for the simple moving average.
%--------------------------------------------------------------------------
% OUTPUTS: output = column vector with computed SMA (the first "int" - 1 
%                   cells are NaN
%-------------------------------------------------------------------------
    output=NaN(size(X,1),1);
    if (rem(int,1) ~= 0)||(int <= 0)
        display('The interval must be a positive integer')
    else
        for i=fix(int/2)+1:size(X,1)-fix(int/2)
            output(i,:) = sum(X(i-fix(int/2):i+fix(int/2),:))/int;
        end
    end
end